/* Copyright 2015 Link Labs LLC.  All rights reserved. */

#ifndef LORAWAN_TEST_STR_UTILS_H_
#define LORAWAN_TEST_STR_UTILS_H_

#include <stdint.h>
#include <stddef.h>

#ifdef __cplusplus
extern "C" {
#endif

void cmd_reformat(char * s);

int str_to_int32(char const * value_str, int32_t * value);

int str_to_uint32(char const * value_str, uint32_t * value);

int str_to_uint8(char const * value_str, uint8_t * value);

int32_t hex_char_to_value(char ch, uint8_t *value);

/**
 * \brief Convert a hex string into an array of bytes.
 *
 * \param[in] hex_str The string of hex characters to convert to byte values.
 * \param[inout] b The buffer to populate with values.
 * \param[in] sz The maximum size of b.
 * \param[out] sz_actual The actual size of b.
 * \return 0 on success or error code.
 */
int32_t hex_string_to_bytes(char const * hex_str, uint8_t * b, size_t sz, size_t * sz_actual);

/**
 * @brief Convert a string to upper case.  Equivalent to nonstandard strupr().
 *
 * @param s The input string.  NULL will cause error.
 * @return 0 on success or error code.
 */
int safestr_toupper(char * s);

/**
 * @brief Convert a string value into an index into table.
 *
 * @param s The string value input.
 * @param table The list of possible values, NULL terminated.
 * @param index The output index.  Index is only modified on a successful
 *      conversion, a default value can be set before calling this function.
 * @return 0 or error code.
 */
int safestr_toIndex(char const * s, char const * const * table, int * index);

#ifdef __cplusplus
}
#endif


#endif /* LORAWAN_TEST_STR_UTILS_H_ */
